@@ -1,4 +1,5 @@
 import os
+from typing import Tuple
 
 import sh
 
@@ -10,6 +11,14 @@ def get_cmd_args(cmd: sh.Command):
     return [e.decode('utf-8') for e in args]
 
 
+def compile_shargs(*args, **kwargs) -> Tuple[list, dict]:
+    shcmd = sh.Command('/bin/ls').bake(*args, **kwargs)
+    return (
+        [a.decode('utf-8') for a in shcmd._partial_baked_args],
+        {'_' + k: i for k, i in shcmd._partial_call_args.items()}
+    )
+
+
 def source(path: str, cmd=None, _cwd='.', _env=os.environ) -> dict:
     ret = {}
     if cmd is None:
